fconcrete.StructuralConcrete.ConcreteBeam module
================================================

.. automodule:: fconcrete.StructuralConcrete.ConcreteBeam
    :members:
    :undoc-members:
    :show-inheritance:
